#ifndef CELL_PREVIEW_WIDGET_H
#define CELL_PREVIEW_WIDGET_H

/*!
  \file
  \brief セルのプレビュー表示ウィジット

  \author Satofumi KAMIMURA

  $Id: CellPreviewWidget.h 262 2009-01-30 13:25:37Z satofumi $
*/

#include <QWidget>
#include <memory>


/*!
  \brief セルのプレビュー用ウィジット
*/
class CellPreviewWidget : public QWidget
{
  Q_OBJECT;

  CellPreviewWidget(const CellPreviewWidget& rhs);
  CellPreviewWidget& operator = (const CellPreviewWidget& rhs);

  struct pImpl;
  std::auto_ptr<pImpl> pimpl;

public:
  /*!
    \brief コンストラクタ

    \param[in] parent 親ウィジット
  */
  CellPreviewWidget(QWidget* parent = 0);
  ~CellPreviewWidget(void);

  // !!!
};

#endif /* !CELL_PREVIEW_WIDGET_H */
